@@ -21,6 +21,8 @@ private slots:
   void OpenPlaylistItem(const QString);
   void OpenRecentFile();
   void ClearRecentFiles();
+  void CopyCurrentUrl();
+  void DownloadCurrentVideo();
   void About();
   void OpenHomePage();
   void PlayRemoteVideo();
